@@ -5,7 +5,7 @@ check() {
 	[ "${1}" = "-d" ] && return 0
 
 	# Verify the zfs tool chain
-	for tool in "/usr/bin/zgenhostid" "/sbin/zpool" "/sbin/zfs" "/sbin/mount.zfs" ; do
+	for tool in "/sbin/zgenhostid" "/sbin/zpool" "/sbin/zfs" "/sbin/mount.zfs" ; do
 		test -x "$tool" || return 1
 	done
 	# Verify grep exists
@@ -38,7 +38,7 @@ install() {
 	inst_rules /lib/udev/rules.d/60-zvol.rules
 	dracut_install hostid
 	dracut_install grep
-	dracut_install /usr/bin/zgenhostid
+	dracut_install /sbin/zgenhostid
 	dracut_install /sbin/zfs
 	dracut_install /sbin/zpool
 	# Workaround for https://github.com/openzfs/zfs/issues/4749 by
